# ==============================================================================
# extract fitted values
# ==============================================================================


fitted.mi.method <- function(object,...){
    object@expected
}
